==> react-molecule-accordion-2.3.0.tgz: package/lib/AccordionItemPanel.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef } from 'react';
import { isFragment } from 'react-is';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { inject, combineProps } from '@s-ui/react-primitive-injector';
import Poly from '@s-ui/react-atom-polymorphic-element';
import { useAccordionContext } from './context/index.js';
import { BASE_CLASS_ELEMENT, BASE_CLASS_ITEM_PANEL, BASE_CLASS_ITEM_PANEL_CONTENT } from './settings.js';
import useMeasure from './hook/useMeasure.js';
import AccordionItemPanelDefaultChildren from './AccordionItemPanelDefaultChildren.js';
import { jsx as _jsx } from "react/jsx-runtime";
var AccordionItemPanel = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var as = _ref.as,
      id = _ref.id,
      headerId = _ref.headerId,
      content = _ref.content,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? /*#__PURE__*/_jsx(AccordionItemPanelDefaultChildren, {}) : _ref$children,
      isExpanded = _ref.isExpanded,
      maxHeightProp = _ref.maxHeight,
      value = _ref.value,
      animationDurationProp = _ref.animationDuration,
      disabled = _ref.disabled;

  var _useMeasure = useMeasure(),
      contentRef = _useMeasure[0],
      height = _useMeasure[1].height;

  var _useAccordionContext = useAccordionContext({
    isExpanded: isExpanded,
    value: value
  }),
      values = _useAccordionContext.values,
      animationDurationContext = _useAccordionContext.animationDuration,
      maxHeightContext = _useAccordionContext.maxHeight;

  var maxHeight = maxHeightProp !== undefined ? maxHeightProp : maxHeightContext;
  var animationDuration = animationDurationProp || animationDurationContext;
  return /*#__PURE__*/_jsx("div", {
    id: id,
    ref: forwardedRef,
    role: "region",
    className: cx(BASE_CLASS_ITEM_PANEL, BASE_CLASS_ELEMENT),
    "aria-expanded": values.includes(value),
    "aria-labelledby": headerId,
    "aria-disabled": disabled,
    style: _extends({
      overflowY: height > maxHeight && maxHeight !== 0 ? 'scroll' : 'hidden',
      transition: "max-height " + animationDuration + "ms " + (values.includes(value) ? 'ease-out' : 'ease-in') + ", opacity 0s linear " + (values.includes(value) ? 0 : animationDuration) + "ms, border-top-width 0s linear " + (values.includes(value) ? 0 : animationDuration) + "ms"
    }, values.includes(value) && {
      maxHeight: maxHeight === 0 ? height : maxHeight
    }),
    children: /*#__PURE__*/_jsx(Poly, _extends({
      as: as
    }, _extends({}, !isFragment && {
      className: BASE_CLASS_ITEM_PANEL_CONTENT + "Wrapper"
    }), {
      children: /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS_ITEM_PANEL_CONTENT + "WrapperRef",
        ref: contentRef,
        children: inject(children, [{
          props: _extends({}, content && {
            children: content
          }, {
            isExpanded: isExpanded,
            values: values,
            value: value,
            disabled: disabled
          }),
          proviso: function proviso() {
            return true;
          },
          combine: combineProps
        }])
      })
    }))
  });
});
AccordionItemPanel.displayName = 'AccordionItemPanel';
export default AccordionItemPanel;

==> react-molecule-accordion-2.4.0.tgz: package/lib/AccordionItemPanel.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef } from 'react';
import { isFragment } from 'react-is';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { inject, combineProps } from '@s-ui/react-primitive-injector';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { useAccordionContext } from './context/index.js';
import { BASE_CLASS_ELEMENT, BASE_CLASS_ITEM_PANEL, BASE_CLASS_ITEM_PANEL_CONTENT } from './settings.js';
import useMeasure from './hook/useMeasure.js';
import AccordionItemPanelDefaultChildren from './AccordionItemPanelDefaultChildren.js';
import { jsx as _jsx } from "react/jsx-runtime";
var AccordionItemPanel = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var as = _ref.as,
      id = _ref.id,
      headerId = _ref.headerId,
      content = _ref.content,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? /*#__PURE__*/_jsx(AccordionItemPanelDefaultChildren, {}) : _ref$children,
      isExpanded = _ref.isExpanded,
      maxHeightProp = _ref.maxHeight,
      value = _ref.value,
      animationDurationProp = _ref.animationDuration,
      disabled = _ref.disabled;

  var _useMeasure = useMeasure(),
      contentRef = _useMeasure[0],
      height = _useMeasure[1].height;

  var _useAccordionContext = useAccordionContext({
    isExpanded: isExpanded,
    value: value
  }),
      values = _useAccordionContext.values,
      animationDurationContext = _useAccordionContext.animationDuration,
      maxHeightContext = _useAccordionContext.maxHeight;

  var maxHeight = maxHeightProp !== undefined ? maxHeightProp : maxHeightContext;
  var animationDuration = animationDurationProp || animationDurationContext;
  return /*#__PURE__*/_jsx("div", {
    id: id,
    ref: forwardedRef,
    role: "region",
    className: cx(BASE_CLASS_ITEM_PANEL, BASE_CLASS_ELEMENT),
    "aria-expanded": values.includes(value),
    "aria-labelledby": headerId,
    "aria-disabled": disabled,
    style: _extends({
      overflowY: height > maxHeight && maxHeight !== 0 ? 'scroll' : 'hidden',
      transition: "max-height " + animationDuration + "ms " + (values.includes(value) ? 'ease-out' : 'ease-in') + ", opacity 0s linear " + (values.includes(value) ? 0 : animationDuration) + "ms, border-top-width 0s linear " + (values.includes(value) ? 0 : animationDuration) + "ms"
    }, values.includes(value) && {
      maxHeight: maxHeight === 0 ? height : maxHeight
    }),
    children: /*#__PURE__*/_jsx(Poly, _extends({
      as: as
    }, _extends({}, !isFragment && {
      className: BASE_CLASS_ITEM_PANEL_CONTENT + "Wrapper"
    }), {
      children: /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS_ITEM_PANEL_CONTENT + "WrapperRef",
        ref: contentRef,
        children: inject(children, [{
          props: _extends({}, content && {
            children: content
          }, {
            isExpanded: isExpanded,
            values: values,
            value: value,
            disabled: disabled
          }),
          proviso: function proviso() {
            return true;
          },
          combine: combineProps
        }])
      })
    }))
  });
});
AccordionItemPanel.displayName = 'AccordionItemPanel';
export default AccordionItemPanel;
